Index: src/arm/lithium-codegen-arm.cc |
=================================================================== |
--- src/arm/lithium-codegen-arm.cc (revision 9308) |
+++ src/arm/lithium-codegen-arm.cc (working copy) |
@@ -83,9 +83,11 @@ |
CpuFeatures::Scope scope1(VFP3); |
CpuFeatures::Scope scope2(ARMv7); |
+ CodeStub::GenerateFPStubs(); |
+ |
// Open a frame scope to indicate that there is a frame on the stack. The |
// NONE indicates that the scope shouldn't actually generate code to set up |
// the frame (that is done in GeneatePrologue). |
FrameScope frame_scope(masm_, StackFrame::NONE); |
return GeneratePrologue() && |
@@ -83,9 +83,11 @@ |
// Open a frame scope to indicate that there is a frame on the stack. The |
// NONE indicates that the scope shouldn't actually generate code to set up |
- // the frame (that is done in GeneatePrologue). |
+ // the frame (that is done in GeneratePrologue). |
FrameScope frame_scope(masm_, StackFrame::NONE); |
return GeneratePrologue() && |